@@ -1,4 +1,6 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="ca">
 <context>
     <name>NetFileChooseEdit</name>
     <message>
@@ -13,6 +15,37 @@
         <translation>Cal</translation>
     </message>
 </context>
+<context>
+    <name>NetUtils</name>
+    <message>
+        <source>Off</source>
+        <translation>Desactivat</translation>
+    </message>
+    <message>
+        <source>Connected</source>
+        <translation>Connectat</translation>
+    </message>
+    <message>
+        <source>IP conflict</source>
+        <translation>Conflicte d&apos;IP</translation>
+    </message>
+    <message>
+        <source>Connecting</source>
+        <translation>Es connecta</translation>
+    </message>
+    <message>
+        <source>Obtaining address</source>
+        <translation>S&apos;obté l&apos;adreça</translation>
+    </message>
+    <message>
+        <source>Authenticating</source>
+        <translation>S&apos;autentica</translation>
+    </message>
+    <message>
+        <source>Disconnected</source>
+        <translation>Desconnectat</translation>
+    </message>
+</context>
 <context>
     <name>PageAirplane</name>
     <message>
@@ -124,10 +157,6 @@
 </context>
 <context>
     <name>PageDSLSettings</name>
-    <message>
-        <source> Network Properties</source>
-        <translation>Propietats de xarxa</translation>
-    </message>
     <message>
         <source>Delete</source>
         <translation>Elimina</translation>
@@ -144,6 +173,10 @@
         <source>Save</source>
         <translation>Desa-ho</translation>
     </message>
+    <message>
+        <source>%1 Network Properties</source>
+        <translation>Propietats de la xarxa %1</translation>
+    </message>
 </context>
 <context>
     <name>PageDetails</name>
@@ -262,13 +295,13 @@
         <source>If you want to use the personal hotspot, disable &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;Airplane Mode&lt;/a&gt; first and then enable the wireless network adapter.</source>
         <translation>Si voleu usar el punt d&apos;accés personal, desactiveu primer el &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;Mode d&apos;avió&lt;/a&gt; i després activeu l&apos;adaptador de xarxa sense fil.</translation>
     </message>
+    <message>
+        <source>Enable &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network&apos;&gt;Wireless Network Adapter&lt;/a&gt; first if you want to use the personal hotspot.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PageSettings</name>
-    <message>
-        <source> Network Properties</source>
-        <translation>Propietats de xarxa</translation>
-    </message>
     <message>
         <source>Delete</source>
         <translation>Elimina</translation>
@@ -285,6 +318,10 @@
         <source>Save</source>
         <translation>Desa-ho</translation>
     </message>
+    <message>
+        <source>%1 Network Properties</source>
+        <translation>Propietats de la xarxa %1</translation>
+    </message>
 </context>
 <context>
     <name>PageSystemProxy</name>
@@ -390,38 +427,10 @@
 </context>
 <context>
     <name>PageVPNSettings</name>
-    <message>
-        <source> Network Properties</source>
-        <translation>Propietats de xarxa</translation>
-    </message>
     <message>
         <source>VPN Type</source>
         <translation>Tipus d&apos;XPV</translation>
     </message>
-    <message>
-        <source>L2TP</source>
-        <translation>L2TP</translation>
-    </message>
-    <message>
-        <source>PPTP</source>
-        <translation>PPTP</translation>
-    </message>
-    <message>
-        <source>OpenVPN</source>
-        <translation>OpenVPN</translation>
-    </message>
-    <message>
-        <source>OpenConnect</source>
-        <translation>OpenConnect</translation>
-    </message>
-    <message>
-        <source>StrongSwan</source>
-        <translation>StrongSwan</translation>
-    </message>
-    <message>
-        <source>VPNC</source>
-        <translation>VPNC</translation>
-    </message>
     <message>
         <source>Delete</source>
         <translation>Elimina</translation>
@@ -446,6 +455,10 @@
         <source>Save</source>
         <translation>Desa-ho</translation>
     </message>
+    <message>
+        <source>%1 Network Properties</source>
+        <translation>Propietats de la xarxa %1</translation>
+    </message>
 </context>
 <context>
     <name>PageWiredDevice</name>
@@ -484,10 +497,6 @@
         <source>Connect</source>
         <translation>Connecta</translation>
     </message>
-    <message>
-        <source>My Networks</source>
-        <translation>Les meves xarxes</translation>
-    </message>
     <message>
         <source>Other Networks</source>
         <translation>Altres xarxes</translation>
@@ -508,6 +517,10 @@
         <source>&lt;a style=&apos;text-decoration: none;&apos; href=&apos;NetHotspotControlItem&apos;&gt;Disable hotspot&lt;/a&gt; first if you want to connect to a wireless network</source>
         <translation>&lt;a style=&apos;text-decoration: none;&apos; href=&apos;NetHotspotControlItem&apos;&gt;Inhabiliteu primer el punt d&apos;accés&lt;/a&gt; si voleu connectar-vos a una xarxa sense fil.</translation>
     </message>
+    <message>
+        <source>My Networks</source>
+        <translation>Les meves xarxes</translation>
+    </message>
 </context>
 <context>
     <name>SectionDNS</name>
@@ -554,10 +567,6 @@
         <source>Customize MTU</source>
         <translation>Personalitzeu l&apos;MTU</translation>
     </message>
-    <message>
-        <source>MTU</source>
-        <translation>MTU</translation>
-    </message>
     <message>
         <source>Band</source>
         <translation>Banda</translation>
@@ -574,6 +583,10 @@
         <source>5 GHz</source>
         <translation>5 GHz</translation>
     </message>
+    <message>
+        <source>MTU (1280-9000)</source>
+        <translation>MTU (1280-9000)</translation>
+    </message>
 </context>
 <context>
     <name>SectionGeneric</name>
@@ -812,18 +825,6 @@
         <source>Security</source>
         <translation>Seguretat</translation>
     </message>
-    <message>
-        <source>TLS</source>
-        <translation>TLS</translation>
-    </message>
-    <message>
-        <source>MD5</source>
-        <translation>MD5</translation>
-    </message>
-    <message>
-        <source>FAST</source>
-        <translation>RÀPID</translation>
-    </message>
     <message>
         <source>Tunneled TLS</source>
         <translation>TLS per túnel</translation>
@@ -832,30 +833,6 @@
         <source>Protected EAP</source>
         <translation>EAP protegit</translation>
     </message>
-    <message>
-        <source>LEAP</source>
-        <translation>SALT</translation>
-    </message>
-    <message>
-        <source>GTC</source>
-        <translation>GTC</translation>
-    </message>
-    <message>
-        <source>MSCHAPV2</source>
-        <translation>MSCHAPV2</translation>
-    </message>
-    <message>
-        <source>PAP</source>
-        <translation>PAP</translation>
-    </message>
-    <message>
-        <source>MSCHAP</source>
-        <translation>MSCHAP</translation>
-    </message>
-    <message>
-        <source>CHAP</source>
-        <translation>CHAP</translation>
-    </message>
     <message>
         <source>None</source>
         <translation>Cap</translation>
@@ -1295,10 +1272,6 @@
         <source>Customize Tunnel MTU</source>
         <translation>Personalitzeu el túnel d&apos;MTU</translation>
     </message>
-    <message>
-        <source>MTU</source>
-        <translation>MTU</translation>
-    </message>
     <message>
         <source>Customize UDP Fragment Size</source>
         <translation>Personalitzeu la mida de fragment d&apos;UPD</translation>
@@ -1419,70 +1392,6 @@
         <source>Default</source>
         <translation>Per defecte</translation>
     </message>
-    <message>
-        <source>DES-CBC</source>
-        <translation>DES-CBC</translation>
-    </message>
-    <message>
-        <source>RC2-CBC</source>
-        <translation>RC2-CBC</translation>
-    </message>
-    <message>
-        <source>DES-EDE-CBC</source>
-        <translation>DES-EDE-CBC</translation>
-    </message>
-    <message>
-        <source>DES-EDE3-CBC</source>
-        <translation>DES-EDE3-CBC</translation>
-    </message>
-    <message>
-        <source>DESX-CBC</source>
-        <translation>DESX-CBC</translation>
-    </message>
-    <message>
-        <source>BF-CBC</source>
-        <translation>BF-CBC</translation>
-    </message>
-    <message>
-        <source>RC2-40-CBC</source>
-        <translation>RC2-40-CBC</translation>
-    </message>
-    <message>
-        <source>CAST5-CBC</source>
-        <translation>CAST5-CBC</translation>
-    </message>
-    <message>
-        <source>RC2-64-CBC</source>
-        <translation>RC2-64-CBC</translation>
-    </message>
-    <message>
-        <source>AES-128-CBC</source>
-        <translation>AES-128-CBC</translation>
-    </message>
-    <message>
-        <source>AES-192-CBC</source>
-        <translation>AES-192-CBC</translation>
-    </message>
-    <message>
-        <source>AES-256-CBC</source>
-        <translation>AES-256-CBC</translation>
-    </message>
-    <message>
-        <source>CAMELLIA-128-CBC</source>
-        <translation>CAMELLIA-128-CBC</translation>
-    </message>
-    <message>
-        <source>CAMELLIA-192-CBC</source>
-        <translation>CAMELLIA-192-CBC</translation>
-    </message>
-    <message>
-        <source>CAMELLIA-256-CBC</source>
-        <translation>CAMELLIA-256-CBC</translation>
-    </message>
-    <message>
-        <source>SEED-CBC</source>
-        <translation>SEED-CBC</translation>
-    </message>
     <message>
         <source>HMAC Auth</source>
         <translation>Autenticació HMAC</translation>
@@ -1527,14 +1436,6 @@
         <source>Proxy Type</source>
         <translation>Tipus de servidor intermediari</translation>
     </message>
-    <message>
-        <source>HTTP</source>
-        <translation>HTTP</translation>
-    </message>
-    <message>
-        <source>SOCKS</source>
-        <translation>SOCKS</translation>
-    </message>
     <message>
         <source>Server IP</source>
         <translation>IP del servidor</translation>
@@ -1571,6 +1472,10 @@
         <source>Key File</source>
         <translation>Fitxer de clau</translation>
     </message>
+    <message>
+        <source>MTU (1280-9000)</source>
+        <translation>MTU (1280-9000)</translation>
+    </message>
 </context>
 <context>
     <name>SystemProxyConfigItem</name>
@@ -1744,4 +1649,15 @@
         <translation>Xarxa</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+<context>
+    <name>networkMain</name>
+    <message>
+        <source>Connection settings</source>
+        <translation>Configuració de la connexió</translation>
+    </message>
+    <message>
+        <source>Related Settings</source>
+        <translation>Paràmetres relacionats</translation>
+    </message>
+</context>
+</TS>
