@@ -15,6 +15,37 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>NetUtils</name>
+    <message>
+        <source>Off</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Connected</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>IP conflict</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Connecting</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Obtaining address</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Authenticating</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Disconnected</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>PageAirplane</name>
     <message>
@@ -126,10 +157,6 @@
 </context>
 <context>
     <name>PageDSLSettings</name>
-    <message>
-        <source> Network Properties</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Delete</source>
         <translation type="unfinished"></translation>
@@ -146,6 +173,10 @@
         <source>Save</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>%1 Network Properties</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PageDetails</name>
@@ -264,13 +295,13 @@
         <source>If you want to use the personal hotspot, disable &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;Airplane Mode&lt;/a&gt; first and then enable the wireless network adapter.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Enable &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network&apos;&gt;Wireless Network Adapter&lt;/a&gt; first if you want to use the personal hotspot.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PageSettings</name>
-    <message>
-        <source> Network Properties</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Delete</source>
         <translation type="unfinished"></translation>
@@ -287,6 +318,10 @@
         <source>Save</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>%1 Network Properties</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PageSystemProxy</name>
@@ -392,38 +427,10 @@
 </context>
 <context>
     <name>PageVPNSettings</name>
-    <message>
-        <source> Network Properties</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>VPN Type</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>L2TP</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>PPTP</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>OpenVPN</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>OpenConnect</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>StrongSwan</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>VPNC</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Delete</source>
         <translation type="unfinished"></translation>
@@ -448,6 +455,10 @@
         <source>Save</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>%1 Network Properties</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PageWiredDevice</name>
@@ -486,10 +497,6 @@
         <source>Connect</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>My&#xa0;Networks</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Other Networks</source>
         <translation type="unfinished"></translation>
@@ -510,6 +517,10 @@
         <source>&lt;a style=&apos;text-decoration: none;&apos; href=&apos;NetHotspotControlItem&apos;&gt;Disable hotspot&lt;/a&gt; first if you want to connect to a wireless network</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>My Networks</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SectionDNS</name>
@@ -556,10 +567,6 @@
         <source>Customize MTU</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>MTU</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Band</source>
         <translation type="unfinished"></translation>
@@ -576,6 +583,10 @@
         <source>5 GHz</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>MTU (1280-9000)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SectionGeneric</name>
@@ -814,18 +825,6 @@
         <source>Security</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>TLS</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>MD5</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>FAST</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Tunneled TLS</source>
         <translation type="unfinished"></translation>
@@ -834,30 +833,6 @@
         <source>Protected EAP</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>LEAP</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>GTC</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>MSCHAPV2</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>PAP</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>MSCHAP</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>CHAP</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>None</source>
         <translation type="unfinished"></translation>
@@ -1297,10 +1272,6 @@
         <source>Customize Tunnel MTU</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>MTU</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Customize UDP Fragment Size</source>
         <translation type="unfinished"></translation>
@@ -1421,70 +1392,6 @@
         <source>Default</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>DES-CBC</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>RC2-CBC</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>DES-EDE-CBC</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>DES-EDE3-CBC</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>DESX-CBC</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>BF-CBC</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>RC2-40-CBC</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>CAST5-CBC</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>RC2-64-CBC</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>AES-128-CBC</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>AES-192-CBC</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>AES-256-CBC</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>CAMELLIA-128-CBC</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>CAMELLIA-192-CBC</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>CAMELLIA-256-CBC</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>SEED-CBC</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>HMAC Auth</source>
         <translation type="unfinished"></translation>
@@ -1529,14 +1436,6 @@
         <source>Proxy Type</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>HTTP</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>SOCKS</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Server IP</source>
         <translation type="unfinished"></translation>
@@ -1573,6 +1472,10 @@
         <source>Key File</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>MTU (1280-9000)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SystemProxyConfigItem</name>
@@ -1746,4 +1649,15 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>networkMain</name>
+    <message>
+        <source>Connection settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Related Settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 </TS>
