@@ -1,4 +1,6 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fr">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="fr">
 <context>
     <name>NetFileChooseEdit</name>
     <message>
@@ -13,6 +15,37 @@
         <translation>Requis</translation>
     </message>
 </context>
+<context>
+    <name>NetUtils</name>
+    <message>
+        <source>Off</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Connected</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>IP conflict</source>
+        <translation type="unfinished">Conflit d&apos;adresses IP</translation>
+    </message>
+    <message>
+        <source>Connecting</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Obtaining address</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Authenticating</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Disconnected</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>PageAirplane</name>
     <message>
@@ -124,10 +157,6 @@
 </context>
 <context>
     <name>PageDSLSettings</name>
-    <message>
-        <source> Network Properties</source>
-        <translation> Propriétés du réseau</translation>
-    </message>
     <message>
         <source>Delete</source>
         <translation>Supprimer</translation>
@@ -144,6 +173,10 @@
         <source>Save</source>
         <translation>Sauvegarder</translation>
     </message>
+    <message>
+        <source>%1 Network Properties</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PageDetails</name>
@@ -262,13 +295,13 @@
         <source>If you want to use the personal hotspot, disable &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;Airplane Mode&lt;/a&gt; first and then enable the wireless network adapter.</source>
         <translation>Si vous souhaitez utiliser le point d&apos;accès personnel, désactivez d&apos;abord le &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;Mode avion&lt;/a&gt;, puis activez la carte réseau sans fil.</translation>
     </message>
+    <message>
+        <source>Enable &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network&apos;&gt;Wireless Network Adapter&lt;/a&gt; first if you want to use the personal hotspot.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PageSettings</name>
-    <message>
-        <source> Network Properties</source>
-        <translation> Propriétés du réseau</translation>
-    </message>
     <message>
         <source>Delete</source>
         <translation>Supprimer</translation>
@@ -285,6 +318,10 @@
         <source>Save</source>
         <translation>Sauvegarder</translation>
     </message>
+    <message>
+        <source>%1 Network Properties</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PageSystemProxy</name>
@@ -390,38 +427,10 @@
 </context>
 <context>
     <name>PageVPNSettings</name>
-    <message>
-        <source> Network Properties</source>
-        <translation> Propriétés du réseau</translation>
-    </message>
     <message>
         <source>VPN Type</source>
         <translation>Type de VPN</translation>
     </message>
-    <message>
-        <source>L2TP</source>
-        <translation>L2TP</translation>
-    </message>
-    <message>
-        <source>PPTP</source>
-        <translation>PPTP</translation>
-    </message>
-    <message>
-        <source>OpenVPN</source>
-        <translation>OpenVPN</translation>
-    </message>
-    <message>
-        <source>OpenConnect</source>
-        <translation>OpenConnect</translation>
-    </message>
-    <message>
-        <source>StrongSwan</source>
-        <translation>StrongSwan</translation>
-    </message>
-    <message>
-        <source>VPNC</source>
-        <translation>VPNC</translation>
-    </message>
     <message>
         <source>Delete</source>
         <translation>Supprimer</translation>
@@ -446,6 +455,10 @@
         <source>Save</source>
         <translation>Sauvegarder</translation>
     </message>
+    <message>
+        <source>%1 Network Properties</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PageWiredDevice</name>
@@ -484,10 +497,6 @@
         <source>Connect</source>
         <translation>Connecter</translation>
     </message>
-    <message>
-        <source>My Networks</source>
-        <translation>Mes réseaux  </translation>
-    </message>
     <message>
         <source>Other Networks</source>
         <translation>Autres réseaux</translation>
@@ -508,6 +517,10 @@
         <source>&lt;a style=&apos;text-decoration: none;&apos; href=&apos;NetHotspotControlItem&apos;&gt;Disable hotspot&lt;/a&gt; first if you want to connect to a wireless network</source>
         <translation>&lt;a style=&apos;text-decoration: none;&apos; href=&apos;NetHotspotControlItem&apos;&gt;Désactivez le point d&apos;accès&lt;/a&gt; si vous souhaitez vous connecter à un réseau sans fil.</translation>
     </message>
+    <message>
+        <source>My Networks</source>
+        <translation type="unfinished">Mes réseaux</translation>
+    </message>
 </context>
 <context>
     <name>SectionDNS</name>
@@ -554,10 +567,6 @@
         <source>Customize MTU</source>
         <translation>Personnaliser la MTU</translation>
     </message>
-    <message>
-        <source>MTU</source>
-        <translation>MTU</translation>
-    </message>
     <message>
         <source>Band</source>
         <translation>Bande</translation>
@@ -574,6 +583,10 @@
         <source>5 GHz</source>
         <translation>5 GHz</translation>
     </message>
+    <message>
+        <source>MTU (1280-9000)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SectionGeneric</name>
@@ -812,18 +825,6 @@
         <source>Security</source>
         <translation>Sécurité</translation>
     </message>
-    <message>
-        <source>TLS</source>
-        <translation>TLS</translation>
-    </message>
-    <message>
-        <source>MD5</source>
-        <translation>MD5</translation>
-    </message>
-    <message>
-        <source>FAST</source>
-        <translation>FAST</translation>
-    </message>
     <message>
         <source>Tunneled TLS</source>
         <translation>TLS en tunnel</translation>
@@ -832,30 +833,6 @@
         <source>Protected EAP</source>
         <translation>EAP protégé</translation>
     </message>
-    <message>
-        <source>LEAP</source>
-        <translation>LEAP</translation>
-    </message>
-    <message>
-        <source>GTC</source>
-        <translation>GTC</translation>
-    </message>
-    <message>
-        <source>MSCHAPV2</source>
-        <translation>MSCHAPV2</translation>
-    </message>
-    <message>
-        <source>PAP</source>
-        <translation>PAP</translation>
-    </message>
-    <message>
-        <source>MSCHAP</source>
-        <translation>MSCHAP</translation>
-    </message>
-    <message>
-        <source>CHAP</source>
-        <translation>CHAP</translation>
-    </message>
     <message>
         <source>None</source>
         <translation>Aucun</translation>
@@ -1295,10 +1272,6 @@
         <source>Customize Tunnel MTU</source>
         <translation>Personnaliser le tunnel MTU</translation>
     </message>
-    <message>
-        <source>MTU</source>
-        <translation>MTU</translation>
-    </message>
     <message>
         <source>Customize UDP Fragment Size</source>
         <translation>Personnaliser la taille des fragments UDP</translation>
@@ -1419,70 +1392,6 @@
         <source>Default</source>
         <translation>Défaut</translation>
     </message>
-    <message>
-        <source>DES-CBC</source>
-        <translation>DES-CBC</translation>
-    </message>
-    <message>
-        <source>RC2-CBC</source>
-        <translation>RC2-CBC</translation>
-    </message>
-    <message>
-        <source>DES-EDE-CBC</source>
-        <translation>DES-EDE-CBC</translation>
-    </message>
-    <message>
-        <source>DES-EDE3-CBC</source>
-        <translation>DES-EDE3-CBC</translation>
-    </message>
-    <message>
-        <source>DESX-CBC</source>
-        <translation>DESX-CBC</translation>
-    </message>
-    <message>
-        <source>BF-CBC</source>
-        <translation>BF-CBC</translation>
-    </message>
-    <message>
-        <source>RC2-40-CBC</source>
-        <translation>RC2-40-CBC</translation>
-    </message>
-    <message>
-        <source>CAST5-CBC</source>
-        <translation>CAST5-CBC</translation>
-    </message>
-    <message>
-        <source>RC2-64-CBC</source>
-        <translation>RC2-64-CBC</translation>
-    </message>
-    <message>
-        <source>AES-128-CBC</source>
-        <translation>AES-128-CBC</translation>
-    </message>
-    <message>
-        <source>AES-192-CBC</source>
-        <translation>AES-192-CBC</translation>
-    </message>
-    <message>
-        <source>AES-256-CBC</source>
-        <translation>AES-256-CBC</translation>
-    </message>
-    <message>
-        <source>CAMELLIA-128-CBC</source>
-        <translation>CAMELLIA-128-CBC</translation>
-    </message>
-    <message>
-        <source>CAMELLIA-192-CBC</source>
-        <translation>CAMELLIA-192-CBC</translation>
-    </message>
-    <message>
-        <source>CAMELLIA-256-CBC</source>
-        <translation>CAMELLIA-256-CBC</translation>
-    </message>
-    <message>
-        <source>SEED-CBC</source>
-        <translation>SEED-CBC</translation>
-    </message>
     <message>
         <source>HMAC Auth</source>
         <translation>Authentification HMAC</translation>
@@ -1527,14 +1436,6 @@
         <source>Proxy Type</source>
         <translation>Type de proxy</translation>
     </message>
-    <message>
-        <source>HTTP</source>
-        <translation>HTTP</translation>
-    </message>
-    <message>
-        <source>SOCKS</source>
-        <translation>SOCKS</translation>
-    </message>
     <message>
         <source>Server IP</source>
         <translation>IP du serveur</translation>
@@ -1571,6 +1472,10 @@
         <source>Key File</source>
         <translation>Fichier clé</translation>
     </message>
+    <message>
+        <source>MTU (1280-9000)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SystemProxyConfigItem</name>
@@ -1744,4 +1649,15 @@
         <translation>Réseau</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+<context>
+    <name>networkMain</name>
+    <message>
+        <source>Connection settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Related Settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+</TS>
