@@ -1,4 +1,6 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="lo">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="lo">
 <context>
     <name>NetFileChooseEdit</name>
     <message>
@@ -13,6 +15,37 @@
         <translation>ຈຳເປັນ</translation>
     </message>
 </context>
+<context>
+    <name>NetUtils</name>
+    <message>
+        <source>Off</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Connected</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>IP conflict</source>
+        <translation type="unfinished">ຄວາມຂັດແຍ້ງ IP</translation>
+    </message>
+    <message>
+        <source>Connecting</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Obtaining address</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Authenticating</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Disconnected</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>PageAirplane</name>
     <message>
@@ -124,10 +157,6 @@
 </context>
 <context>
     <name>PageDSLSettings</name>
-    <message>
-        <source> Network Properties</source>
-        <translation>ຄຸນສົມບັດເຄືອຂ່າຍ</translation>
-    </message>
     <message>
         <source>Delete</source>
         <translation>ລົບ</translation>
@@ -144,6 +173,10 @@
         <source>Save</source>
         <translation>ບັນທຶກ</translation>
     </message>
+    <message>
+        <source>%1 Network Properties</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PageDetails</name>
@@ -262,13 +295,13 @@
         <source>If you want to use the personal hotspot, disable &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;Airplane Mode&lt;/a&gt; first and then enable the wireless network adapter.</source>
         <translation>ຫາກທ່ານຕ້ອງການໃຊ້ hotspot ສ່ວນຕົວ, ກະລຸນາປິດ&lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;ໂມດຄານບິນ&lt;/a&gt;ແລ້ວເປີດອັດເຕອ່ເຄືອຂ່າຍໄວ້ລີສ</translation>
     </message>
+    <message>
+        <source>Enable &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network&apos;&gt;Wireless Network Adapter&lt;/a&gt; first if you want to use the personal hotspot.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PageSettings</name>
-    <message>
-        <source> Network Properties</source>
-        <translation> ຄຸນສົມບັດເຄືອຂ່າຍ</translation>
-    </message>
     <message>
         <source>Delete</source>
         <translation>ລົບ</translation>
@@ -286,6 +319,10 @@
         <source>Save</source>
         <translation>ບັນທຶກ</translation>
     </message>
+    <message>
+        <source>%1 Network Properties</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PageSystemProxy</name>
@@ -391,38 +428,10 @@
 </context>
 <context>
     <name>PageVPNSettings</name>
-    <message>
-        <source> Network Properties</source>
-        <translation>ສຳລັບເບິ່ງປົກກະຕິ</translation>
-    </message>
     <message>
         <source>VPN Type</source>
         <translation>ປະເພາະVPN</translation>
     </message>
-    <message>
-        <source>L2TP</source>
-        <translation>L2TP</translation>
-    </message>
-    <message>
-        <source>PPTP</source>
-        <translation>PPTP</translation>
-    </message>
-    <message>
-        <source>OpenVPN</source>
-        <translation>OpenVPN</translation>
-    </message>
-    <message>
-        <source>OpenConnect</source>
-        <translation>OpenConnect</translation>
-    </message>
-    <message>
-        <source>StrongSwan</source>
-        <translation>StrongSwan</translation>
-    </message>
-    <message>
-        <source>VPNC</source>
-        <translation>VPNC</translation>
-    </message>
     <message>
         <source>Delete</source>
         <translation>ລົບ</translation>
@@ -447,6 +456,10 @@
         <source>Save</source>
         <translation>ບັນທຶກ</translation>
     </message>
+    <message>
+        <source>%1 Network Properties</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PageWiredDevice</name>
@@ -485,10 +498,6 @@
         <source>Connect</source>
         <translation>ເຊື່ອມຕໍ່</translation>
     </message>
-    <message>
-        <source>My Networks</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Other Networks</source>
         <translation>ເຄືອຂ່າຍອື່ນໆ</translation>
@@ -509,6 +518,10 @@
         <source>&lt;a style=&apos;text-decoration: none;&apos; href=&apos;NetHotspotControlItem&apos;&gt;Disable hotspot&lt;/a&gt; first if you want to connect to a wireless network</source>
         <translation>&lt;a style=&apos;text-decoration: none;&apos; href=&apos;NetHotspotControlItem&apos;&gt;ປິດຮັອດສະປອດ&lt;/a&gt; ກ່ອນຖ້າທ່ານຕ້ອງການເຊື່ອມຕໍ່ກັບເຄືອຂ່າຍໄຮ້ສາຍ</translation>
     </message>
+    <message>
+        <source>My Networks</source>
+        <translation type="unfinished">ສະຖານະການເຊື່ອມຕໍ່ຂອງຂ້ອຍ</translation>
+    </message>
 </context>
 <context>
     <name>SectionDNS</name>
@@ -555,10 +568,6 @@
         <source>Customize MTU</source>
         <translation>ກຳນົດ MTU ເອງ</translation>
     </message>
-    <message>
-        <source>MTU</source>
-        <translation>MTU</translation>
-    </message>
     <message>
         <source>Band</source>
         <translation>ຄື່ນຄວາມຖີ່</translation>
@@ -575,6 +584,10 @@
         <source>5 GHz</source>
         <translation>5 GHz</translation>
     </message>
+    <message>
+        <source>MTU (1280-9000)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SectionGeneric</name>
@@ -813,18 +826,6 @@
         <source>Security</source>
         <translation>ຄວາມປອດໄພ</translation>
     </message>
-    <message>
-        <source>TLS</source>
-        <translation>TLS</translation>
-    </message>
-    <message>
-        <source>MD5</source>
-        <translation>MD5</translation>
-    </message>
-    <message>
-        <source>FAST</source>
-        <translation>FAST</translation>
-    </message>
     <message>
         <source>Tunneled TLS</source>
         <translation>TLS ແບບອຸໂມງ</translation>
@@ -833,30 +834,6 @@
         <source>Protected EAP</source>
         <translation>EAP ທີ່ມີການປົກປ້ອງ</translation>
     </message>
-    <message>
-        <source>LEAP</source>
-        <translation>LEAP</translation>
-    </message>
-    <message>
-        <source>GTC</source>
-        <translation>GTC</translation>
-    </message>
-    <message>
-        <source>MSCHAPV2</source>
-        <translation>MSCHAPV2</translation>
-    </message>
-    <message>
-        <source>PAP</source>
-        <translation>PAP</translation>
-    </message>
-    <message>
-        <source>MSCHAP</source>
-        <translation>MSCHAP</translation>
-    </message>
-    <message>
-        <source>CHAP</source>
-        <translation>CHAP</translation>
-    </message>
     <message>
         <source>None</source>
         <translation>ບໍ່ມີ</translation>
@@ -1296,10 +1273,6 @@
         <source>Customize Tunnel MTU</source>
         <translation>ກຳນົດ MTU ອຸໂມງເອງ</translation>
     </message>
-    <message>
-        <source>MTU</source>
-        <translation>MTU</translation>
-    </message>
     <message>
         <source>Customize UDP Fragment Size</source>
         <translation>ກຳນົດຂະໜາດສ່ວນ UDP ເອງ</translation>
@@ -1420,70 +1393,6 @@
         <source>Default</source>
         <translation>ຄ່າເລີ່ມຕົ້ນ</translation>
     </message>
-    <message>
-        <source>DES-CBC</source>
-        <translation>DES-CBC</translation>
-    </message>
-    <message>
-        <source>RC2-CBC</source>
-        <translation>RC2-CBC</translation>
-    </message>
-    <message>
-        <source>DES-EDE-CBC</source>
-        <translation>DES-EDE-CBC</translation>
-    </message>
-    <message>
-        <source>DES-EDE3-CBC</source>
-        <translation>DES-EDE3-CBC</translation>
-    </message>
-    <message>
-        <source>DESX-CBC</source>
-        <translation>DESX-CBC</translation>
-    </message>
-    <message>
-        <source>BF-CBC</source>
-        <translation>BF-CBC</translation>
-    </message>
-    <message>
-        <source>RC2-40-CBC</source>
-        <translation>RC2-40-CBC</translation>
-    </message>
-    <message>
-        <source>CAST5-CBC</source>
-        <translation>CAST5-CBC</translation>
-    </message>
-    <message>
-        <source>RC2-64-CBC</source>
-        <translation>RC2-64-CBC</translation>
-    </message>
-    <message>
-        <source>AES-128-CBC</source>
-        <translation>AES-128-CBC</translation>
-    </message>
-    <message>
-        <source>AES-192-CBC</source>
-        <translation>AES-192-CBC</translation>
-    </message>
-    <message>
-        <source>AES-256-CBC</source>
-        <translation>AES-256-CBC</translation>
-    </message>
-    <message>
-        <source>CAMELLIA-128-CBC</source>
-        <translation>CAMELLIA-128-CBC</translation>
-    </message>
-    <message>
-        <source>CAMELLIA-192-CBC</source>
-        <translation>CAMELLIA-192-CBC</translation>
-    </message>
-    <message>
-        <source>CAMELLIA-256-CBC</source>
-        <translation>CAMELLIA-256-CBC</translation>
-    </message>
-    <message>
-        <source>SEED-CBC</source>
-        <translation>SEED-CBC</translation>
-    </message>
     <message>
         <source>HMAC Auth</source>
         <translation>HMAC Auth</translation>
@@ -1522,82 +1431,78 @@
     </message>
     <message>
         <source>VPN Proxy</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>Proxy Type</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>HTTP</source>
-        <translation>HTTP</translation>
-    </message>
-    <message>
-        <source>SOCKS</source>
-        <translation>SOCKS</translation>
+        <translation type="unfinished">ປະເພດພຣອກຊີ</translation>
     </message>
     <message>
         <source>Server IP</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>Port</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished">ພອດ</translation>
     </message>
     <message>
         <source>Retry Indefinitely When Failed</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>VPN TLS Authentication</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>Subject Match</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>Remote Cert Type</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>Client</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>Server</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>Key File</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>MTU (1280-9000)</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>SystemProxyConfigItem</name>
     <message>
         <source>Optional</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished">ທາງເລືອກ</translation>
     </message>
     <message>
         <source>Port</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished">ພອດ</translation>
     </message>
     <message>
         <source>Authentication is required</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>Username</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished">ຊື່ຜູ້ໃຊ້</translation>
     </message>
     <message>
         <source>Required</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished">ຈຳເປັນ</translation>
     </message>
     <message>
         <source>Password</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished">ລະຫັດຜ່ານ</translation>
     </message>
 </context>
 <context>
@@ -1742,7 +1647,18 @@
     <name>network</name>
     <message>
         <source>Network</source>
-        <translation type="unfinished"/>
+        <translation>ເຄືອຂ່າຍ</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+<context>
+    <name>networkMain</name>
+    <message>
+        <source>Connection settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Related Settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+</TS>
