@@ -1,4 +1,6 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="pl">
 <context>
     <name>NetFileChooseEdit</name>
     <message>
@@ -13,6 +15,37 @@
         <translation>Wymagane</translation>
     </message>
 </context>
+<context>
+    <name>NetUtils</name>
+    <message>
+        <source>Off</source>
+        <translation>Wyłączony</translation>
+    </message>
+    <message>
+        <source>Connected</source>
+        <translation>Połączono</translation>
+    </message>
+    <message>
+        <source>IP conflict</source>
+        <translation>Konflikt IP</translation>
+    </message>
+    <message>
+        <source>Connecting</source>
+        <translation>Łączenie</translation>
+    </message>
+    <message>
+        <source>Obtaining address</source>
+        <translation>Uzyskiwanie adresu</translation>
+    </message>
+    <message>
+        <source>Authenticating</source>
+        <translation>Uwierzytelnianie</translation>
+    </message>
+    <message>
+        <source>Disconnected</source>
+        <translation>Rozłączono</translation>
+    </message>
+</context>
 <context>
     <name>PageAirplane</name>
     <message>
@@ -124,10 +157,6 @@
 </context>
 <context>
     <name>PageDSLSettings</name>
-    <message>
-        <source> Network Properties</source>
-        <translation> Ustawienia sieci</translation>
-    </message>
     <message>
         <source>Delete</source>
         <translation>Usuń</translation>
@@ -144,6 +173,10 @@
         <source>Save</source>
         <translation>Zapisz</translation>
     </message>
+    <message>
+        <source>%1 Network Properties</source>
+        <translation>%1 Ustawienia sieci</translation>
+    </message>
 </context>
 <context>
     <name>PageDetails</name>
@@ -262,13 +295,13 @@
         <source>If you want to use the personal hotspot, disable &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;Airplane Mode&lt;/a&gt; first and then enable the wireless network adapter.</source>
         <translation>Jeśli chcesz korzystać z osobistego Hotspota, najpierw wyłącz &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Tryb samolotowy&lt;/a&gt; i włącz bezprzewodową kartę sieciową.</translation>
     </message>
+    <message>
+        <source>Enable &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network&apos;&gt;Wireless Network Adapter&lt;/a&gt; first if you want to use the personal hotspot.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PageSettings</name>
-    <message>
-        <source> Network Properties</source>
-        <translation> Ustawienia sieci</translation>
-    </message>
     <message>
         <source>Delete</source>
         <translation>Usuń</translation>
@@ -285,6 +318,10 @@
         <source>Save</source>
         <translation>Zapisz</translation>
     </message>
+    <message>
+        <source>%1 Network Properties</source>
+        <translation>%1 Ustawienia sieci</translation>
+    </message>
 </context>
 <context>
     <name>PageSystemProxy</name>
@@ -390,38 +427,10 @@
 </context>
 <context>
     <name>PageVPNSettings</name>
-    <message>
-        <source> Network Properties</source>
-        <translation> Ustawienia sieci</translation>
-    </message>
     <message>
         <source>VPN Type</source>
         <translation>Typ VPN</translation>
     </message>
-    <message>
-        <source>L2TP</source>
-        <translation>L2TP</translation>
-    </message>
-    <message>
-        <source>PPTP</source>
-        <translation>PPTP</translation>
-    </message>
-    <message>
-        <source>OpenVPN</source>
-        <translation>OpenVPN</translation>
-    </message>
-    <message>
-        <source>OpenConnect</source>
-        <translation>OpenConnect</translation>
-    </message>
-    <message>
-        <source>StrongSwan</source>
-        <translation>StrongSwan</translation>
-    </message>
-    <message>
-        <source>VPNC</source>
-        <translation>VPNC</translation>
-    </message>
     <message>
         <source>Delete</source>
         <translation>Usuń</translation>
@@ -446,6 +455,10 @@
         <source>Save</source>
         <translation>Zapisz</translation>
     </message>
+    <message>
+        <source>%1 Network Properties</source>
+        <translation>%1 Ustawienia sieci</translation>
+    </message>
 </context>
 <context>
     <name>PageWiredDevice</name>
@@ -484,10 +497,6 @@
         <source>Connect</source>
         <translation>Połącz</translation>
     </message>
-    <message>
-        <source>My Networks</source>
-        <translation>Moje sieci</translation>
-    </message>
     <message>
         <source>Other Networks</source>
         <translation>Inne sieci</translation>
@@ -508,6 +517,10 @@
         <source>&lt;a style=&apos;text-decoration: none;&apos; href=&apos;NetHotspotControlItem&apos;&gt;Disable hotspot&lt;/a&gt; first if you want to connect to a wireless network</source>
         <translation>Najpierw &lt;a style=&apos;text-decoration: none;&apos; href=&apos;NetHotspotControlItem&apos;&gt;wyłącz Hotspot&lt;/a&gt;, aby połączyć się z siecią bezprzewodową</translation>
     </message>
+    <message>
+        <source>My Networks</source>
+        <translation>Moje sieci</translation>
+    </message>
 </context>
 <context>
     <name>SectionDNS</name>
@@ -554,10 +567,6 @@
         <source>Customize MTU</source>
         <translation>Dostosuj MTU</translation>
     </message>
-    <message>
-        <source>MTU</source>
-        <translation>MTU</translation>
-    </message>
     <message>
         <source>Band</source>
         <translation>Pasmo</translation>
@@ -574,6 +583,10 @@
         <source>5 GHz</source>
         <translation>5 GHz</translation>
     </message>
+    <message>
+        <source>MTU (1280-9000)</source>
+        <translation>MTU (1280-9000)</translation>
+    </message>
 </context>
 <context>
     <name>SectionGeneric</name>
@@ -812,18 +825,6 @@
         <source>Security</source>
         <translation>Bezpieczeństwo</translation>
     </message>
-    <message>
-        <source>TLS</source>
-        <translation>TLS</translation>
-    </message>
-    <message>
-        <source>MD5</source>
-        <translation>MD5</translation>
-    </message>
-    <message>
-        <source>FAST</source>
-        <translation>FAST</translation>
-    </message>
     <message>
         <source>Tunneled TLS</source>
         <translation>Tunelowany TLS</translation>
@@ -832,30 +833,6 @@
         <source>Protected EAP</source>
         <translation>Zabezpieczony EAP</translation>
     </message>
-    <message>
-        <source>LEAP</source>
-        <translation>LEAP</translation>
-    </message>
-    <message>
-        <source>GTC</source>
-        <translation>GTC</translation>
-    </message>
-    <message>
-        <source>MSCHAPV2</source>
-        <translation>MSCHAPV2</translation>
-    </message>
-    <message>
-        <source>PAP</source>
-        <translation>PAP</translation>
-    </message>
-    <message>
-        <source>MSCHAP</source>
-        <translation>MSCHAP</translation>
-    </message>
-    <message>
-        <source>CHAP</source>
-        <translation>CHAP</translation>
-    </message>
     <message>
         <source>None</source>
         <translation>Brak</translation>
@@ -1295,10 +1272,6 @@
         <source>Customize Tunnel MTU</source>
         <translation>Dostosuj tunel MTU</translation>
     </message>
-    <message>
-        <source>MTU</source>
-        <translation>MTU</translation>
-    </message>
     <message>
         <source>Customize UDP Fragment Size</source>
         <translation>Dostosuj rozmiar fragmentu UDP</translation>
@@ -1419,70 +1392,6 @@
         <source>Default</source>
         <translation>Domyślny</translation>
     </message>
-    <message>
-        <source>DES-CBC</source>
-        <translation>DES-CBC</translation>
-    </message>
-    <message>
-        <source>RC2-CBC</source>
-        <translation>RC2-CBC</translation>
-    </message>
-    <message>
-        <source>DES-EDE-CBC</source>
-        <translation>DES-EDE-CBC</translation>
-    </message>
-    <message>
-        <source>DES-EDE3-CBC</source>
-        <translation>DES-EDE3-CBC</translation>
-    </message>
-    <message>
-        <source>DESX-CBC</source>
-        <translation>DESX-CBC</translation>
-    </message>
-    <message>
-        <source>BF-CBC</source>
-        <translation>BF-CBC</translation>
-    </message>
-    <message>
-        <source>RC2-40-CBC</source>
-        <translation>RC2-40-CBC</translation>
-    </message>
-    <message>
-        <source>CAST5-CBC</source>
-        <translation>CAST5-CBC</translation>
-    </message>
-    <message>
-        <source>RC2-64-CBC</source>
-        <translation>RC2-64-CBC</translation>
-    </message>
-    <message>
-        <source>AES-128-CBC</source>
-        <translation>AES-128-CBC</translation>
-    </message>
-    <message>
-        <source>AES-192-CBC</source>
-        <translation>AES-192-CBC</translation>
-    </message>
-    <message>
-        <source>AES-256-CBC</source>
-        <translation>AES-256-CBC</translation>
-    </message>
-    <message>
-        <source>CAMELLIA-128-CBC</source>
-        <translation>CAMELLIA-128-CBC</translation>
-    </message>
-    <message>
-        <source>CAMELLIA-192-CBC</source>
-        <translation>CAMELLIA-192-CBC</translation>
-    </message>
-    <message>
-        <source>CAMELLIA-256-CBC</source>
-        <translation>CAMELLIA-256-CBC</translation>
-    </message>
-    <message>
-        <source>SEED-CBC</source>
-        <translation>SEED-CBC</translation>
-    </message>
     <message>
         <source>HMAC Auth</source>
         <translation>Uwierzytelnienie HMAC</translation>
@@ -1527,14 +1436,6 @@
         <source>Proxy Type</source>
         <translation>Typ proxy</translation>
     </message>
-    <message>
-        <source>HTTP</source>
-        <translation>HTTP</translation>
-    </message>
-    <message>
-        <source>SOCKS</source>
-        <translation>SOCKS</translation>
-    </message>
     <message>
         <source>Server IP</source>
         <translation>IP serwera</translation>
@@ -1571,6 +1472,10 @@
         <source>Key File</source>
         <translation>Plik klucza</translation>
     </message>
+    <message>
+        <source>MTU (1280-9000)</source>
+        <translation>MTU (1280-9000)</translation>
+    </message>
 </context>
 <context>
     <name>SystemProxyConfigItem</name>
@@ -1681,7 +1586,7 @@
     </message>
     <message>
         <source>The &quot;%1&quot; 802.11 WLAN network could not be found</source>
-        <translation>Nie można znaleźć sieci WLAN &quot;%1&quot; 802.11</translation>
+        <translation>Nie można znaleźć sieci WLAN 802.11 &quot;%1&quot;</translation>
     </message>
     <message>
         <source>To connect &quot;%1&quot;, please set up your authentication info after logging in</source>
@@ -1744,4 +1649,15 @@
         <translation>Sieć</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+<context>
+    <name>networkMain</name>
+    <message>
+        <source>Connection settings</source>
+        <translation>Ustawienia sieci</translation>
+    </message>
+    <message>
+        <source>Related Settings</source>
+        <translation>Powiązane ustawienia</translation>
+    </message>
+</context>
+</TS>
