@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="zh_CN">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
 <context>
     <name>dde::hotspotplugin::HotspotPlugin</name>
     <message>
@@ -31,4 +29,4 @@
         <translation>热点</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
