@@ -1,312 +1,310 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="lt">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="lt">
 <context>
     <name>dde::network::DockContentWidget</name>
     <message>
         <source>Network settings</source>
-        <translation type="unfinished">Tinklo nustatymai</translation>
+        <translation>Tinklo nustatymai</translation>
     </message>
     <message>
         <source>Network Detection</source>
-        <translation type="unfinished"></translation>
+        <translation>Tinklo aptikimas</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetAirplaneModeTipsItem</name>
     <message>
         <source>Disable &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Airplane Mode&lt;/a&gt; first if you want to connect to a wireless network</source>
-        <translation type="unfinished"></translation>
+        <translation>Norėdami prisijungti prie belaidžio tinklo, pirmiausia, išjunkite &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Lėktuvo veikseną&lt;/a&gt;</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetManagerPrivate</name>
     <message>
         <source>IP conflict</source>
-        <translation type="unfinished"></translation>
+        <translation>IP adresų konfliktas</translation>
     </message>
     <message>
         <source>Network</source>
-        <translation type="unfinished">Tinklas</translation>
+        <translation>Tinklas</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetManagerThreadPrivate</name>
     <message>
         <source>Wired Connection %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>VPN L2TP %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>VPN PPTP %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>VPN VPNC %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>VPN OpenVPN %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>VPN StrongSwan %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>VPN OpenConnect %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>PPPoE Connection %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Connecting &quot;%1&quot;</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>&quot;%1&quot; connected</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>&quot;%1&quot; disconnected</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Unable to connect &quot;%1&quot;, please check your router or net cable.</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Unable to connect &quot;%1&quot;, please keep closer to the wireless router</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Connection failed, unable to connect &quot;%1&quot;, wrong password</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Password is required to connect &quot;%1&quot;</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>The &quot;%1&quot; 802.11 WLAN network could not be found</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>To connect &quot;%1&quot;, please set up your authentication info after logging in</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
     <name>dde::network::NetSecretWidget</name>
     <message>
         <source>Password</source>
-        <translation type="unfinished">Slaptažodis</translation>
+        <translation>Slaptažodis</translation>
     </message>
     <message>
         <source>Private Pwd</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>key</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Proxy Password</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Group Password</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Username</source>
-        <translation type="unfinished"></translation>
+        <translation>Naudotojo vardas</translation>
     </message>
     <message>
         <source>Name (SSID)</source>
-        <translation type="unfinished"></translation>
+        <translation>Pavadinimas (SSID)</translation>
     </message>
     <message>
         <source>Cancel</source>
         <comment>button</comment>
-        <translation type="unfinished">Atsisakyti</translation>
+        <translation>Atsisakyti</translation>
     </message>
     <message>
         <source>Connect</source>
         <comment>button</comment>
-        <translation type="unfinished">Prisijungti</translation>
+        <translation>Prisijungti</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetStatus</name>
     <message>
         <source>Disable wired connection</source>
-        <translation type="unfinished">Išjungti laidinį ryšį</translation>
+        <translation>Išjungti laidinį ryšį</translation>
     </message>
     <message>
         <source>Enable wired connection</source>
-        <translation type="unfinished">Įjungti laidinį ryšį</translation>
+        <translation>Įjungti laidinį ryšį</translation>
     </message>
     <message>
         <source>Disable wireless connection</source>
-        <translation type="unfinished">Išjungti belaidį ryšį</translation>
+        <translation>Išjungti belaidį ryšį</translation>
     </message>
     <message>
         <source>Enable wireless connection</source>
-        <translation type="unfinished">Įjungti belaidį ryšį</translation>
+        <translation>Įjungti belaidį ryšį</translation>
     </message>
     <message>
         <source>Disable network</source>
-        <translation type="unfinished">Išjungti tinklą</translation>
+        <translation>Išjungti tinklą</translation>
     </message>
     <message>
         <source>Enable network</source>
-        <translation type="unfinished">Įjungti tinklą</translation>
+        <translation>Įjungti tinklą</translation>
     </message>
     <message>
         <source>Disable VPN</source>
-        <translation type="unfinished"></translation>
+        <translation>Išjungti VPN</translation>
     </message>
     <message>
         <source>Enable VPN</source>
-        <translation type="unfinished"></translation>
+        <translation>Įjungti VPN</translation>
     </message>
     <message>
         <source>Disable system proxy</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Enable system proxy</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Network settings</source>
-        <translation type="unfinished">Tinklo nustatymai</translation>
+        <translation>Tinklo nustatymai</translation>
     </message>
     <message>
         <source>Multiple services started</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Connected to: %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Prisijungta prie: %1</translation>
     </message>
     <message>
         <source>System proxy enabled</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Connected</source>
-        <translation type="unfinished">Prisijungta</translation>
+        <translation>Prisijungta</translation>
     </message>
     <message>
         <source>Network off</source>
-        <translation type="unfinished"></translation>
+        <translation>Tinklas išjungtas</translation>
     </message>
     <message>
         <source>Network cable unplugged</source>
-        <translation type="unfinished">Atjungtas tinklo laidas</translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Not connected</source>
-        <translation type="unfinished">Neprijungta</translation>
+        <translation>Neprisijungta</translation>
     </message>
     <message>
         <source>Connecting</source>
-        <translation type="unfinished">Jungiamasi</translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Connected but no Internet access</source>
-        <translation type="unfinished">Prisijungta, bet nėra prieigos prie interneto</translation>
+        <translation>Prisijungta, bet nėra prieigos prie interneto</translation>
     </message>
     <message>
         <source>Connection failed</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>IP conflict</source>
-        <translation type="unfinished"></translation>
+        <translation>IP adresų konfliktas</translation>
     </message>
     <message>
         <source>Wireless Network</source>
-        <translation type="unfinished">Belaidis tinklas</translation>
+        <translation>Belaidis tinklas</translation>
     </message>
     <message>
         <source>Connected %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Off</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Wired Network</source>
-        <translation type="unfinished">Laidinis tinklas</translation>
+        <translation>Laidinis tinklas</translation>
     </message>
     <message>
         <source>Network</source>
-        <translation type="unfinished">Tinklas</translation>
+        <translation>Tinklas</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetSystemProxyControlItem</name>
     <message>
         <source>System Proxy</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
     <name>dde::network::NetVPNTipsItem</name>
     <message>
         <source>VPN configuration is not connected or failed to connect. Please &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;go to the control center&lt;/a&gt; for inspection.</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
     <name>dde::network::NetWiredControlItem</name>
     <message>
         <source>Wired Network</source>
-        <translation type="unfinished">Laidinis tinklas</translation>
+        <translation>Laidinis tinklas</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessControlItem</name>
     <message>
         <source>Wireless Network</source>
-        <translation type="unfinished">Belaidis tinklas</translation>
+        <translation>Belaidis tinklas</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessHiddenItem</name>
     <message>
         <source>Connect to hidden network</source>
-        <translation type="unfinished">Prisijungti prie paslėpto tinklo</translation>
+        <translation>Prisijungti prie paslėpto tinklo</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessMineItem</name>
     <message>
         <source>My Networks</source>
-        <translation type="unfinished"></translation>
+        <translation>Mano tinklai</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessOtherItem</name>
     <message>
         <source>Other Networks</source>
-        <translation type="unfinished"></translation>
+        <translation>Kiti tinklai</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetworkPlugin</name>
     <message>
         <source>Network</source>
-        <translation type="unfinished">Tinklas</translation>
+        <translation>Tinklas</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
