@@ -1,312 +1,310 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="tr">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr">
 <context>
     <name>dde::network::DockContentWidget</name>
     <message>
         <source>Network settings</source>
-        <translation type="unfinished">Ay ayarları</translation>
+        <translation>Ay ayarları</translation>
     </message>
     <message>
         <source>Network Detection</source>
-        <translation type="unfinished"></translation>
+        <translation>Ağ Algılama</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetAirplaneModeTipsItem</name>
     <message>
         <source>Disable &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Airplane Mode&lt;/a&gt; first if you want to connect to a wireless network</source>
-        <translation type="unfinished"></translation>
+        <translation>Kablosuz bir ağa bağlanmak istiyorsanız öncelikle &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Uçak Modunu&lt;/a&gt; devre dışı bırakın</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetManagerPrivate</name>
     <message>
         <source>IP conflict</source>
-        <translation type="unfinished">IP çakışması</translation>
+        <translation>IP çakışması</translation>
     </message>
     <message>
         <source>Network</source>
-        <translation type="unfinished">Ağ</translation>
+        <translation>Ağ</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetManagerThreadPrivate</name>
     <message>
         <source>Wired Connection %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Kablolu Bağlantı %1</translation>
     </message>
     <message>
         <source>VPN L2TP %1</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN L2TP %1</translation>
     </message>
     <message>
         <source>VPN PPTP %1</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN PPTP %1</translation>
     </message>
     <message>
         <source>VPN VPNC %1</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN VPNC %1</translation>
     </message>
     <message>
         <source>VPN OpenVPN %1</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN OpenVPN %1</translation>
     </message>
     <message>
         <source>VPN StrongSwan %1</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN StrongSwan %1</translation>
     </message>
     <message>
         <source>VPN OpenConnect %1</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN OpenConnect %1</translation>
     </message>
     <message>
         <source>PPPoE Connection %1</source>
-        <translation type="unfinished"></translation>
+        <translation>PPPoE Bğlantısı %1</translation>
     </message>
     <message>
         <source>Connecting &quot;%1&quot;</source>
-        <translation type="unfinished"></translation>
+        <translation>Bağlanıyor &quot;%1&quot;</translation>
     </message>
     <message>
         <source>&quot;%1&quot; connected</source>
-        <translation type="unfinished"></translation>
+        <translation>&quot;%1&quot; bağlandı</translation>
     </message>
     <message>
         <source>&quot;%1&quot; disconnected</source>
-        <translation type="unfinished"></translation>
+        <translation>&quot;%1&quot; bağlantısı kesildi</translation>
     </message>
     <message>
         <source>Unable to connect &quot;%1&quot;, please check your router or net cable.</source>
-        <translation type="unfinished"></translation>
+        <translation>&quot;%1&quot; bağlantısı kurulamıyor, lütfen yönlendiricinizi veya ağ kablonuzu kontrol edin.</translation>
     </message>
     <message>
         <source>Unable to connect &quot;%1&quot;, please keep closer to the wireless router</source>
-        <translation type="unfinished"></translation>
+        <translation>&quot;%1&quot; bağlantısı kurulamıyor, lütfen kablosuz yönlendiriciye daha yakın olun</translation>
     </message>
     <message>
         <source>Connection failed, unable to connect &quot;%1&quot;, wrong password</source>
-        <translation type="unfinished"></translation>
+        <translation>Bağlantı başarısız oldu, &quot;%1&quot;e bağlanılamadı, yanlış parola</translation>
     </message>
     <message>
         <source>Password is required to connect &quot;%1&quot;</source>
-        <translation type="unfinished"></translation>
+        <translation>&quot;%1&quot; &apos;e bağlanmak için parola gerekli</translation>
     </message>
     <message>
         <source>The &quot;%1&quot; 802.11 WLAN network could not be found</source>
-        <translation type="unfinished"></translation>
+        <translation>&quot;%1&quot;  802.11 WLAN ağı bulunamadı</translation>
     </message>
     <message>
         <source>To connect &quot;%1&quot;, please set up your authentication info after logging in</source>
-        <translation type="unfinished"></translation>
+        <translation>&quot;%1&quot;e bağlanmak için lütfen oturum açtıktan sonra kimlik doğrulama bilgilerinizi ayarlayın</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetSecretWidget</name>
     <message>
         <source>Password</source>
-        <translation type="unfinished">Parola</translation>
+        <translation>Parola</translation>
     </message>
     <message>
         <source>Private Pwd</source>
-        <translation type="unfinished"></translation>
+        <translation>Özel Parola</translation>
     </message>
     <message>
         <source>key</source>
-        <translation type="unfinished"></translation>
+        <translation>anahtar</translation>
     </message>
     <message>
         <source>Proxy Password</source>
-        <translation type="unfinished"></translation>
+        <translation>Vekil Sunucu Parolası</translation>
     </message>
     <message>
         <source>Group Password</source>
-        <translation type="unfinished"></translation>
+        <translation>Grup Parolası</translation>
     </message>
     <message>
         <source>Username</source>
-        <translation type="unfinished"></translation>
+        <translation>Kullanıcı adı</translation>
     </message>
     <message>
         <source>Name (SSID)</source>
-        <translation type="unfinished">İsim (SSID)</translation>
+        <translation>İsim (SSID)</translation>
     </message>
     <message>
         <source>Cancel</source>
         <comment>button</comment>
-        <translation type="unfinished">İptal</translation>
+        <translation>İptal</translation>
     </message>
     <message>
         <source>Connect</source>
         <comment>button</comment>
-        <translation type="unfinished">Bağlan</translation>
+        <translation>Bağlan</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetStatus</name>
     <message>
         <source>Disable wired connection</source>
-        <translation type="unfinished">Kablolu bağlantıyı devre dışı bırak</translation>
+        <translation>Kablolu bağlantıyı devre dışı bırak</translation>
     </message>
     <message>
         <source>Enable wired connection</source>
-        <translation type="unfinished">Kablolu bağlantıyı etkinleştir</translation>
+        <translation>Kablolu bağlantıyı etkinleştir</translation>
     </message>
     <message>
         <source>Disable wireless connection</source>
-        <translation type="unfinished">Kablosuz bağlantıyı devre dışı bırak</translation>
+        <translation>Kablosuz bağlantıyı devre dışı bırak</translation>
     </message>
     <message>
         <source>Enable wireless connection</source>
-        <translation type="unfinished">Kablosuz bağlantıyı etkinleştir</translation>
+        <translation>Kablosuz bağlantıyı etkinleştir</translation>
     </message>
     <message>
         <source>Disable network</source>
-        <translation type="unfinished">Ağı devre dışı bırak</translation>
+        <translation>Ağı devre dışı bırak</translation>
     </message>
     <message>
         <source>Enable network</source>
-        <translation type="unfinished">Ağı etkinleştir</translation>
+        <translation>Ağı etkinleştir</translation>
     </message>
     <message>
         <source>Disable VPN</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN devre dışı bırak</translation>
     </message>
     <message>
         <source>Enable VPN</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN etkinleştir</translation>
     </message>
     <message>
         <source>Disable system proxy</source>
-        <translation type="unfinished"></translation>
+        <translation>Sistem proxy&apos;sini devre dışı bırak</translation>
     </message>
     <message>
         <source>Enable system proxy</source>
-        <translation type="unfinished"></translation>
+        <translation>Sistem proxy&apos;sini etkinleştir</translation>
     </message>
     <message>
         <source>Network settings</source>
-        <translation type="unfinished">Ay ayarları</translation>
+        <translation>Ay ayarları</translation>
     </message>
     <message>
         <source>Multiple services started</source>
-        <translation type="unfinished"></translation>
+        <translation>Birden fazla hizmet başlatıldı</translation>
     </message>
     <message>
         <source>Connected to: %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Bağlandı: %1</translation>
     </message>
     <message>
         <source>System proxy enabled</source>
-        <translation type="unfinished"></translation>
+        <translation>Sistem proxy&apos;si etkinleştirildi</translation>
     </message>
     <message>
         <source>Connected</source>
-        <translation type="unfinished">Bağlandı</translation>
+        <translation>Bağlandı</translation>
     </message>
     <message>
         <source>Network off</source>
-        <translation type="unfinished"></translation>
+        <translation>Ağ kapalı</translation>
     </message>
     <message>
         <source>Network cable unplugged</source>
-        <translation type="unfinished">Ağ kablosu takılı değil</translation>
+        <translation>Ağ kablosu takılı değil</translation>
     </message>
     <message>
         <source>Not connected</source>
-        <translation type="unfinished">Bağlı değil</translation>
+        <translation>Bağlı değil</translation>
     </message>
     <message>
         <source>Connecting</source>
-        <translation type="unfinished">Bağlanıyor</translation>
+        <translation>Bağlanıyor</translation>
     </message>
     <message>
         <source>Connected but no Internet access</source>
-        <translation type="unfinished">Bağlandı ancak İnternet erişimi yok</translation>
+        <translation>Bağlandı ancak İnternet erişimi yok</translation>
     </message>
     <message>
         <source>Connection failed</source>
-        <translation type="unfinished">Bağlantı başarısız</translation>
+        <translation>Bağlantı başarısız</translation>
     </message>
     <message>
         <source>IP conflict</source>
-        <translation type="unfinished">IP çakışması</translation>
+        <translation>IP çakışması</translation>
     </message>
     <message>
         <source>Wireless Network</source>
-        <translation type="unfinished">Kablosuz Ağ</translation>
+        <translation>Kablosuz Ağ</translation>
     </message>
     <message>
         <source>Connected %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Bağlandı %1</translation>
     </message>
     <message>
         <source>Off</source>
-        <translation type="unfinished"></translation>
+        <translation>Kapalı</translation>
     </message>
     <message>
         <source>Wired Network</source>
-        <translation type="unfinished">Kablolu Ağ</translation>
+        <translation>Kablolu Ağ</translation>
     </message>
     <message>
         <source>Network</source>
-        <translation type="unfinished">Ağ</translation>
+        <translation>Ağ</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetSystemProxyControlItem</name>
     <message>
         <source>System Proxy</source>
-        <translation type="unfinished"></translation>
+        <translation>Sistem Vekil Sunucusu</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetVPNTipsItem</name>
     <message>
         <source>VPN configuration is not connected or failed to connect. Please &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;go to the control center&lt;/a&gt; for inspection.</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN yapılandırması bağlı değil veya bağlanamadı. Lütfen inceleme için &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;kontrol merkezine gidin.&lt;/a&gt;</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWiredControlItem</name>
     <message>
         <source>Wired Network</source>
-        <translation type="unfinished">Kablolu Ağ</translation>
+        <translation>Kablolu Ağ</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessControlItem</name>
     <message>
         <source>Wireless Network</source>
-        <translation type="unfinished">Kablosuz Ağ</translation>
+        <translation>Kablosuz Ağ</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessHiddenItem</name>
     <message>
         <source>Connect to hidden network</source>
-        <translation type="unfinished">Gizli ağa bağlan</translation>
+        <translation>Gizli ağa bağlan</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessMineItem</name>
     <message>
         <source>My Networks</source>
-        <translation type="unfinished"></translation>
+        <translation>Ağlarım</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessOtherItem</name>
     <message>
         <source>Other Networks</source>
-        <translation type="unfinished"></translation>
+        <translation>Diğer Ağlar</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetworkPlugin</name>
     <message>
         <source>Network</source>
-        <translation type="unfinished">Ağ</translation>
+        <translation>Ağ</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
