@@ -1,312 +1,310 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="uk">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="uk">
 <context>
     <name>dde::network::DockContentWidget</name>
     <message>
         <source>Network settings</source>
-        <translation type="unfinished">Параметри мережі</translation>
+        <translation>Параметри мережі</translation>
     </message>
     <message>
         <source>Network Detection</source>
-        <translation type="unfinished"></translation>
+        <translation>Виявлення мережі</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetAirplaneModeTipsItem</name>
     <message>
         <source>Disable &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Airplane Mode&lt;/a&gt; first if you want to connect to a wireless network</source>
-        <translation type="unfinished"></translation>
+        <translation>Якщо ви хочете встановити з&apos;єднання з бездротовою мережею, спочатку вимкніть &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Режим польоту&lt;/a&gt;</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetManagerPrivate</name>
     <message>
         <source>IP conflict</source>
-        <translation type="unfinished">Конфлікт IP</translation>
+        <translation>Конфлікт IP</translation>
     </message>
     <message>
         <source>Network</source>
-        <translation type="unfinished">Мережа</translation>
+        <translation>Мережа</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetManagerThreadPrivate</name>
     <message>
         <source>Wired Connection %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Дротове з&apos;єднання %1</translation>
     </message>
     <message>
         <source>VPN L2TP %1</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN L2TP %1</translation>
     </message>
     <message>
         <source>VPN PPTP %1</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN PPTP %1</translation>
     </message>
     <message>
         <source>VPN VPNC %1</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN VPNC %1</translation>
     </message>
     <message>
         <source>VPN OpenVPN %1</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN OpenVPN %1</translation>
     </message>
     <message>
         <source>VPN StrongSwan %1</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN StrongSwan %1</translation>
     </message>
     <message>
         <source>VPN OpenConnect %1</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN OpenConnect %1</translation>
     </message>
     <message>
         <source>PPPoE Connection %1</source>
-        <translation type="unfinished"></translation>
+        <translation>З&apos;єднання PPPoE %1</translation>
     </message>
     <message>
         <source>Connecting &quot;%1&quot;</source>
-        <translation type="unfinished"></translation>
+        <translation>Встановлюємо з&apos;єднання із «%1»</translation>
     </message>
     <message>
         <source>&quot;%1&quot; connected</source>
-        <translation type="unfinished"></translation>
+        <translation>З&apos;єднання із «%1» встановлено</translation>
     </message>
     <message>
         <source>&quot;%1&quot; disconnected</source>
-        <translation type="unfinished"></translation>
+        <translation>З&apos;єднання із «%1» розірвано</translation>
     </message>
     <message>
         <source>Unable to connect &quot;%1&quot;, please check your router or net cable.</source>
-        <translation type="unfinished"></translation>
+        <translation>Не вдалося з&apos;єднатися із «%1». Будь ласка, перевірте, чи працює ваш маршрутизатор або мережевий кабель.</translation>
     </message>
     <message>
         <source>Unable to connect &quot;%1&quot;, please keep closer to the wireless router</source>
-        <translation type="unfinished"></translation>
+        <translation>Не вдалося встановити з&apos;єднання із «%1». Будь ласка, підійдіть ближче до бездротового маршрутизатора.</translation>
     </message>
     <message>
         <source>Connection failed, unable to connect &quot;%1&quot;, wrong password</source>
-        <translation type="unfinished"></translation>
+        <translation>Не вдалося встановити з&apos;єднання із «%1». Вказано помилковий пароль.</translation>
     </message>
     <message>
         <source>Password is required to connect &quot;%1&quot;</source>
-        <translation type="unfinished"></translation>
+        <translation>Для встановлення з&apos;єднання із «%1» потрібен пароль</translation>
     </message>
     <message>
         <source>The &quot;%1&quot; 802.11 WLAN network could not be found</source>
-        <translation type="unfinished"></translation>
+        <translation>Не вдалося знайти мережу WLAN 802.11 «%1»</translation>
     </message>
     <message>
         <source>To connect &quot;%1&quot;, please set up your authentication info after logging in</source>
-        <translation type="unfinished"></translation>
+        <translation>Для встановлення з&apos;єднання з «%1», будь ласка, налаштуйте ваші дані для розпізнавання після входу до системи</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetSecretWidget</name>
     <message>
         <source>Password</source>
-        <translation type="unfinished">Пароль</translation>
+        <translation>Пароль</translation>
     </message>
     <message>
         <source>Private Pwd</source>
-        <translation type="unfinished"></translation>
+        <translation>Приватний пароль</translation>
     </message>
     <message>
         <source>key</source>
-        <translation type="unfinished"></translation>
+        <translation>ключ</translation>
     </message>
     <message>
         <source>Proxy Password</source>
-        <translation type="unfinished"></translation>
+        <translation>Пароль до проксі</translation>
     </message>
     <message>
         <source>Group Password</source>
-        <translation type="unfinished"></translation>
+        <translation>Пароль групи</translation>
     </message>
     <message>
         <source>Username</source>
-        <translation type="unfinished"></translation>
+        <translation>Користувач</translation>
     </message>
     <message>
         <source>Name (SSID)</source>
-        <translation type="unfinished">Назва (SSID)</translation>
+        <translation>Назва (SSID)</translation>
     </message>
     <message>
         <source>Cancel</source>
         <comment>button</comment>
-        <translation type="unfinished">Скасувати</translation>
+        <translation>Скасувати</translation>
     </message>
     <message>
         <source>Connect</source>
         <comment>button</comment>
-        <translation type="unfinished">З&apos;єднатися</translation>
+        <translation>З&apos;єднатися</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetStatus</name>
     <message>
         <source>Disable wired connection</source>
-        <translation type="unfinished">Вимкнути дротове з&apos;єднання</translation>
+        <translation>Вимкнути дротове з&apos;єднання</translation>
     </message>
     <message>
         <source>Enable wired connection</source>
-        <translation type="unfinished">Увімкнути дротове з&apos;єднання</translation>
+        <translation>Увімкнути дротове з&apos;єднання</translation>
     </message>
     <message>
         <source>Disable wireless connection</source>
-        <translation type="unfinished">Вимкнути бездротове з&apos;єднання</translation>
+        <translation>Вимкнути бездротове з&apos;єднання</translation>
     </message>
     <message>
         <source>Enable wireless connection</source>
-        <translation type="unfinished">Увімкнути бездротове з&apos;єднання</translation>
+        <translation>Увімкнути бездротове з&apos;єднання</translation>
     </message>
     <message>
         <source>Disable network</source>
-        <translation type="unfinished">Вимкнути мережу</translation>
+        <translation>Вимкнути мережу</translation>
     </message>
     <message>
         <source>Enable network</source>
-        <translation type="unfinished">Увімкнути мережу</translation>
+        <translation>Увімкнути мережу</translation>
     </message>
     <message>
         <source>Disable VPN</source>
-        <translation type="unfinished"></translation>
+        <translation>Вимкнути VPN</translation>
     </message>
     <message>
         <source>Enable VPN</source>
-        <translation type="unfinished"></translation>
+        <translation>Увімкнути VPN</translation>
     </message>
     <message>
         <source>Disable system proxy</source>
-        <translation type="unfinished"></translation>
+        <translation>Вимкнути загальносистемний проксі</translation>
     </message>
     <message>
         <source>Enable system proxy</source>
-        <translation type="unfinished"></translation>
+        <translation>Увімкнути загальносистемний проксі</translation>
     </message>
     <message>
         <source>Network settings</source>
-        <translation type="unfinished">Параметри мережі</translation>
+        <translation>Параметри мережі</translation>
     </message>
     <message>
         <source>Multiple services started</source>
-        <translation type="unfinished"></translation>
+        <translation>Запущено декілька служб</translation>
     </message>
     <message>
         <source>Connected to: %1</source>
-        <translation type="unfinished"></translation>
+        <translation>З&apos;єднано з %1</translation>
     </message>
     <message>
         <source>System proxy enabled</source>
-        <translation type="unfinished"></translation>
+        <translation>Загальносистемний проксі увімкнено</translation>
     </message>
     <message>
         <source>Connected</source>
-        <translation type="unfinished">З&apos;єднано</translation>
+        <translation>З&apos;єднано</translation>
     </message>
     <message>
         <source>Network off</source>
-        <translation type="unfinished"></translation>
+        <translation>Мережу вимкнено</translation>
     </message>
     <message>
         <source>Network cable unplugged</source>
-        <translation type="unfinished">Кабель мережі від&apos;єднано</translation>
+        <translation>Кабель мережі від&apos;єднано</translation>
     </message>
     <message>
         <source>Not connected</source>
-        <translation type="unfinished">Не з&apos;єднано</translation>
+        <translation>Не з&apos;єднано</translation>
     </message>
     <message>
         <source>Connecting</source>
-        <translation type="unfinished">З&apos;єднання</translation>
+        <translation>З&apos;єднання</translation>
     </message>
     <message>
         <source>Connected but no Internet access</source>
-        <translation type="unfinished">З&apos;єднано, але немає доступу до інтернету</translation>
+        <translation>З&apos;єднано, але немає доступу до інтернету</translation>
     </message>
     <message>
         <source>Connection failed</source>
-        <translation type="unfinished">Не вдалося встановити з&apos;єднання</translation>
+        <translation>Не вдалося встановити з&apos;єднання</translation>
     </message>
     <message>
         <source>IP conflict</source>
-        <translation type="unfinished">Конфлікт IP</translation>
+        <translation>Конфлікт IP</translation>
     </message>
     <message>
         <source>Wireless Network</source>
-        <translation type="unfinished">Бездротова мережа</translation>
+        <translation>Бездротова мережа</translation>
     </message>
     <message>
         <source>Connected %1</source>
-        <translation type="unfinished"></translation>
+        <translation>З&apos;єднано з %1</translation>
     </message>
     <message>
         <source>Off</source>
-        <translation type="unfinished"></translation>
+        <translation>Вимк.</translation>
     </message>
     <message>
         <source>Wired Network</source>
-        <translation type="unfinished"></translation>
+        <translation>Дротова мережа</translation>
     </message>
     <message>
         <source>Network</source>
-        <translation type="unfinished">Мережа</translation>
+        <translation>Мережа</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetSystemProxyControlItem</name>
     <message>
         <source>System Proxy</source>
-        <translation type="unfinished"></translation>
+        <translation>Загальносистемний проксі</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetVPNTipsItem</name>
     <message>
         <source>VPN configuration is not connected or failed to connect. Please &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;go to the control center&lt;/a&gt; for inspection.</source>
-        <translation type="unfinished"></translation>
+        <translation>Налаштування VPN не призвели до з&apos;єднання або з&apos;єднання не вдалося встановити. Будь ласка, &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;перейдіть до «Центру керування»&lt;/a&gt;, щоб перевірити, чи усе налаштовано правильно.</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWiredControlItem</name>
     <message>
         <source>Wired Network</source>
-        <translation type="unfinished"></translation>
+        <translation>Дротова мережа</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessControlItem</name>
     <message>
         <source>Wireless Network</source>
-        <translation type="unfinished">Бездротова мережа</translation>
+        <translation>Бездротова мережа</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessHiddenItem</name>
     <message>
         <source>Connect to hidden network</source>
-        <translation type="unfinished">Встановлення з&apos;єднання із прихованою мережею</translation>
+        <translation>Встановлення з&apos;єднання із прихованою мережею</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessMineItem</name>
     <message>
         <source>My Networks</source>
-        <translation type="unfinished"></translation>
+        <translation>Мої мережі</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessOtherItem</name>
     <message>
         <source>Other Networks</source>
-        <translation type="unfinished"></translation>
+        <translation>Інші мережі</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetworkPlugin</name>
     <message>
         <source>Network</source>
-        <translation type="unfinished">Мережа</translation>
+        <translation>Мережа</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
