@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="ca">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca">
 <context>
     <name>Bubble</name>
     <message>
@@ -12,290 +10,290 @@
     <name>dde::network::NetAirplaneModeTipsItem</name>
     <message>
         <source>Disable &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Airplane Mode&lt;/a&gt; first if you want to connect to a wireless network</source>
-        <translation type="unfinished"></translation>
+        <translation>Desactiveu primer el &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;mode d&apos;avió&lt;/a&gt; si voleu fer una connexió amb una xarxa sense fil.</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetManagerPrivate</name>
     <message>
         <source>IP conflict</source>
-        <translation type="unfinished">Conflicte d&apos;IP</translation>
+        <translation>Conflicte d&apos;IP</translation>
     </message>
     <message>
         <source>Network</source>
-        <translation type="unfinished"></translation>
+        <translation>Xarxa</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetManagerThreadPrivate</name>
     <message>
         <source>Wired Connection %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Connexió amb fil %1</translation>
     </message>
     <message>
         <source>VPN L2TP %1</source>
-        <translation type="unfinished"></translation>
+        <translation>XPV L2TP %1</translation>
     </message>
     <message>
         <source>VPN PPTP %1</source>
-        <translation type="unfinished"></translation>
+        <translation>XPV PPTP %1</translation>
     </message>
     <message>
         <source>VPN VPNC %1</source>
-        <translation type="unfinished"></translation>
+        <translation>XPV VPNC %1</translation>
     </message>
     <message>
         <source>VPN OpenVPN %1</source>
-        <translation type="unfinished"></translation>
+        <translation>XPV OpenVPN %1</translation>
     </message>
     <message>
         <source>VPN StrongSwan %1</source>
-        <translation type="unfinished"></translation>
+        <translation>XPV StrongSwan %1</translation>
     </message>
     <message>
         <source>VPN OpenConnect %1</source>
-        <translation type="unfinished"></translation>
+        <translation>XPV OpenConnect %1</translation>
     </message>
     <message>
         <source>PPPoE Connection %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Connexió PPPoE %1</translation>
     </message>
     <message>
         <source>Connecting &quot;%1&quot;</source>
-        <translation type="unfinished"></translation>
+        <translation>Es connecta amb %1</translation>
     </message>
     <message>
         <source>&quot;%1&quot; connected</source>
-        <translation type="unfinished"></translation>
+        <translation>%1 connectat</translation>
     </message>
     <message>
         <source>&quot;%1&quot; disconnected</source>
-        <translation type="unfinished"></translation>
+        <translation>%s desconnectat</translation>
     </message>
     <message>
         <source>Unable to connect &quot;%1&quot;, please check your router or net cable.</source>
-        <translation type="unfinished"></translation>
+        <translation>No es pot connectar amb %1. Comproveu l&apos;encaminador o el cable de xarxa.</translation>
     </message>
     <message>
         <source>Unable to connect &quot;%1&quot;, please keep closer to the wireless router</source>
-        <translation type="unfinished"></translation>
+        <translation>No es pot connectar amb %1. Si us plau, mantingueu-vos a prop de l&apos;encaminador.</translation>
     </message>
     <message>
         <source>Connection failed, unable to connect &quot;%1&quot;, wrong password</source>
-        <translation type="unfinished"></translation>
+        <translation>Ha fallat la connexió. No es pot connectar amb %1: contrasenya incorrecta.</translation>
     </message>
     <message>
         <source>Password is required to connect &quot;%1&quot;</source>
-        <translation type="unfinished"></translation>
+        <translation>Cal la contrasenya per connectar amb %1.</translation>
     </message>
     <message>
         <source>The &quot;%1&quot; 802.11 WLAN network could not be found</source>
-        <translation type="unfinished"></translation>
+        <translation>No s&apos;ha pogut trobar la xarxa WLAN 802.11 %1.</translation>
     </message>
     <message>
         <source>To connect &quot;%1&quot;, please set up your authentication info after logging in</source>
-        <translation type="unfinished"></translation>
+        <translation>Per connectar amb %1, configureu la informació d&apos;autenticació després d&apos;iniciar sessió.</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetSecretWidget</name>
     <message>
         <source>Password</source>
-        <translation type="unfinished">Contrasenya</translation>
+        <translation>Contrasenya</translation>
     </message>
     <message>
         <source>Private Pwd</source>
-        <translation type="unfinished"></translation>
+        <translation>Contrasenya privada</translation>
     </message>
     <message>
         <source>key</source>
-        <translation type="unfinished"></translation>
+        <translation>clau</translation>
     </message>
     <message>
         <source>Proxy Password</source>
-        <translation type="unfinished"></translation>
+        <translation>Contrasenya del servidor intermediari</translation>
     </message>
     <message>
         <source>Group Password</source>
-        <translation type="unfinished"></translation>
+        <translation>Contrasenya de grup</translation>
     </message>
     <message>
         <source>Username</source>
-        <translation type="unfinished"></translation>
+        <translation>Nom d&apos;usuari</translation>
     </message>
     <message>
         <source>Name (SSID)</source>
-        <translation type="unfinished">Nom (SSID)</translation>
+        <translation>Nom (SSID)</translation>
     </message>
     <message>
         <source>Cancel</source>
         <comment>button</comment>
-        <translation type="unfinished">Cancel·la</translation>
+        <translation>Cancel·la</translation>
     </message>
     <message>
         <source>Connect</source>
         <comment>button</comment>
-        <translation type="unfinished">Connecta</translation>
+        <translation>Connecta</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetStatus</name>
     <message>
         <source>Disable wired connection</source>
-        <translation type="unfinished">Inhabilita la connexió amb fil</translation>
+        <translation>Inhabilita la connexió amb fil</translation>
     </message>
     <message>
         <source>Enable wired connection</source>
-        <translation type="unfinished">Habilita la connexió amb fil</translation>
+        <translation>Habilita la connexió amb fil</translation>
     </message>
     <message>
         <source>Disable wireless connection</source>
-        <translation type="unfinished">Inhabilita la connexió sense fil</translation>
+        <translation>Inhabilita la connexió sense fil</translation>
     </message>
     <message>
         <source>Enable wireless connection</source>
-        <translation type="unfinished">Habilita la connexió sense fil</translation>
+        <translation>Habilita la connexió sense fil</translation>
     </message>
     <message>
         <source>Disable network</source>
-        <translation type="unfinished">Inhabilita la xarxa</translation>
+        <translation>Inhabilita la xarxa</translation>
     </message>
     <message>
         <source>Enable network</source>
-        <translation type="unfinished">Habilita la xarxa</translation>
+        <translation>Habilita la xarxa</translation>
     </message>
     <message>
         <source>Disable VPN</source>
-        <translation type="unfinished"></translation>
+        <translation>Desactiva la XPV</translation>
     </message>
     <message>
         <source>Enable VPN</source>
-        <translation type="unfinished"></translation>
+        <translation>Activa la XPV</translation>
     </message>
     <message>
         <source>Disable system proxy</source>
-        <translation type="unfinished"></translation>
+        <translation>Desactiva el servidor intermediari del sistema</translation>
     </message>
     <message>
         <source>Enable system proxy</source>
-        <translation type="unfinished"></translation>
+        <translation>Activa el servidor intermediari del sistema</translation>
     </message>
     <message>
         <source>Network settings</source>
-        <translation type="unfinished">Configuració de la xarxa</translation>
+        <translation>Configuració de la xarxa</translation>
     </message>
     <message>
         <source>Multiple services started</source>
-        <translation type="unfinished"></translation>
+        <translation>Diversos serveis iniciats</translation>
     </message>
     <message>
         <source>Connected to: %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Connectat amb %1</translation>
     </message>
     <message>
         <source>System proxy enabled</source>
-        <translation type="unfinished"></translation>
+        <translation>Servidor intermediari del sistema habilitat</translation>
     </message>
     <message>
         <source>Connected</source>
-        <translation type="unfinished">Connectat</translation>
+        <translation>Connectat</translation>
     </message>
     <message>
         <source>Network off</source>
-        <translation type="unfinished"></translation>
+        <translation>Xarxa desactivada</translation>
     </message>
     <message>
         <source>Network cable unplugged</source>
-        <translation type="unfinished">Cable de xarxa desendollat</translation>
+        <translation>Cable de xarxa desendollat</translation>
     </message>
     <message>
         <source>Not connected</source>
-        <translation type="unfinished">No connectat</translation>
+        <translation>No connectat</translation>
     </message>
     <message>
         <source>Connecting</source>
-        <translation type="unfinished">Es connecta</translation>
+        <translation>Es connecta</translation>
     </message>
     <message>
         <source>Connected but no Internet access</source>
-        <translation type="unfinished">Connectat però sense accés a Internet</translation>
+        <translation>Connectat però sense accés a Internet</translation>
     </message>
     <message>
         <source>Connection failed</source>
-        <translation type="unfinished">Ha fallat la connexió.</translation>
+        <translation>Ha fallat la connexió.</translation>
     </message>
     <message>
         <source>IP conflict</source>
-        <translation type="unfinished">Conflicte d&apos;IP</translation>
+        <translation>Conflicte d&apos;IP</translation>
     </message>
     <message>
         <source>Wireless Network</source>
-        <translation type="unfinished">Xarxa sense fil</translation>
+        <translation>Xarxa sense fil</translation>
     </message>
     <message>
         <source>Connected %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Connectat amb %1</translation>
     </message>
     <message>
         <source>Off</source>
-        <translation type="unfinished"></translation>
+        <translation>Desactivat</translation>
     </message>
     <message>
         <source>Wired Network</source>
-        <translation type="unfinished">Xarxa amb fil</translation>
+        <translation>Xarxa amb fil</translation>
     </message>
     <message>
         <source>Network</source>
-        <translation type="unfinished"></translation>
+        <translation>Xarxa</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetSystemProxyControlItem</name>
     <message>
         <source>System Proxy</source>
-        <translation type="unfinished"></translation>
+        <translation>Servidor intermediari del sistema</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetVPNTipsItem</name>
     <message>
         <source>VPN configuration is not connected or failed to connect. Please &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;go to the control center&lt;/a&gt; for inspection.</source>
-        <translation type="unfinished"></translation>
+        <translation>La configuració de la XPV no està connectada o no s&apos;ha pogut connectar. Si us plau, &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt; aneu al centre de control&lt;/a&gt; per inspeccionar-ho.</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWiredControlItem</name>
     <message>
         <source>Wired Network</source>
-        <translation type="unfinished">Xarxa amb fil</translation>
+        <translation>Xarxa amb fil</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessControlItem</name>
     <message>
         <source>Wireless Network</source>
-        <translation type="unfinished">Xarxa sense fil</translation>
+        <translation>Xarxa sense fil</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessHiddenItem</name>
     <message>
         <source>Connect to hidden network</source>
-        <translation type="unfinished">Connecta amb una xarxa oculta</translation>
+        <translation>Connecta amb una xarxa oculta</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessMineItem</name>
     <message>
         <source>My Networks</source>
-        <translation type="unfinished"></translation>
+        <translation>Les meves xarxes</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessOtherItem</name>
     <message>
         <source>Other Networks</source>
-        <translation type="unfinished"></translation>
+        <translation>Altres xarxes</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
