@@ -23,15 +23,19 @@ public:
     explicit NetHotspotController(QObject *parent = nullptr);
     bool isEnabled() const;
     bool enabledable() const;
+    bool deviceEnabled();
     const QVariantMap &config() const;
     const QStringList &optionalDevice() const;
+    const QStringList &optionalDevicePath() const;
     const QStringList &shareDevice() const;
 
 Q_SIGNALS:
     void enabledChanged(const bool);
     void enabledableChanged(const bool);
+    void deviceEnabledChanged(const bool);
     void configChanged(const QVariantMap &config);
     void optionalDeviceChanged(const QStringList &optionalDevice);
+    void optionalDevicePathChanged(const QStringList &optionalDevicePath);
     void shareDeviceChanged(const QStringList &shareDevice);
 
 private Q_SLOTS:
@@ -44,9 +48,11 @@ private:
     HotspotController *m_hotspotController;
     bool m_isEnabled;
     bool m_enabledable;
+    bool m_deviceEnabled;
     QVariantMap m_config;
     QStringList m_shareDevice;
     QStringList m_optionalDevice;
+    QStringList m_optionalDevicePath;
     QTimer *m_updatedTimer;
 };
 } // namespace network
